function [S] = panel_model( N )
% State-space model of the water heating panel: (Rad Tair Te0) -> Ten
% Parameter
% N: number of discretization cells

% Pipe geometry:
L = 100; % m
d_ext = 10e-3; % m
d_in = 9e-3; % m

% Copper and water characteritics:
rho_CU= 8920; % density kg/m3
Cp_Cu = 380; % specific heat J/kg/K
rho_eau = 1000; % density kg/m3
Cp_eau = 4185; % specific heat J/kg/K

% Water mass flow:
q = 0.05; % (kg/s)

% Heat transfer coefficients
h_Cu_eau = h_water_pipe(q, d_in); %(W/m/K)
h_Cu_air = 10; %(W/m/K)

% Sun absorbtion efficiency (with kW -> W conversion)
pAbsorbtion=0.8*1000;

% Parameters of the discretized cells
l=L/N;
Se_eau_Cu = l*pi*d_in; % copper-water exchange surface
Se_air_Cu = l*pi*d_ext; % air-copper exchange surface
S_Cu_Rad = l*d_ext; % insolated surface
Veau = l*pi*d_in^2/4;
VCu = l*pi*d_ext^2/4 -Veau;
me=Veau*rho_eau;
mu=VCu*rho_CU;

% Equation for each discrete cell (i)
% * Water:
%   dTei/dt = 1/(mei*Cp_eau)*(h_Cu_eau*Se_eau_Cu*(Tui-Tei)
%             + q*Cp_eau*(Ti-1-Ti))
% * Copper:
%   dTui/dt = 1/(mui*Cp_Cu)*(h_Cu_eau*Se_eau_Cu*(Tei-Tui)
%             + S_Cu_Rad*pAbsorbtion*Rad
%             + Se_air_Cu*h_CU_air*(Tair-Tui))

% Vector stacking convention:
% X=[... Tei Tui Tei-1 Tui-1 ...]'
% U=[Rad Tair Te0]'
% Y=[Ten] (output water temperature)

D=[0 0 0];

C = [1 zeros(1,2*N-1)];
A =[ -(h_Cu_eau*Se_eau_Cu +q*Cp_eau)/(me*Cp_eau), h_Cu_eau*Se_eau_Cu/(me*Cp_eau);
    1/(mu*Cp_Cu)*(h_Cu_eau*Se_eau_Cu), -1/(mu*Cp_Cu)*(h_Cu_eau*Se_eau_Cu +Se_air_Cu*h_Cu_air)];
B= [0 0 q*Cp_eau/(me*Cp_eau); S_Cu_Rad*pAbsorbtion/(mu*Cp_Cu) Se_air_Cu*h_Cu_air/(mu*Cp_Cu) 0];

Ai =[ -(h_Cu_eau*Se_eau_Cu +q*Cp_eau)/(me*Cp_eau),  h_Cu_eau*Se_eau_Cu/(me*Cp_eau), q*Cp_eau/(me*Cp_eau);
    1/(mu*Cp_Cu)*(h_Cu_eau*Se_eau_Cu), -1/(mu*Cp_Cu)*(h_Cu_eau*Se_eau_Cu +Se_air_Cu*h_Cu_air), 0];
Bi= [0 0 0; S_Cu_Rad*pAbsorbtion/(mu*Cp_Cu) Se_air_Cu*h_Cu_air/(mu*Cp_Cu) 0];

for i=1:(N-1)
    A=[Ai zeros(2,2*i-1); zeros(2*i,2) A];
    B=[Bi;B];
end

S=ss(A,B,C,D);

S.InputName = {'Rad';'Tair';'Te0'};
S.InputUnit = {'kW';'K';'K'};
S.OutputName = 'Ten';
S.OutputUnit = 'K';

end

